@@ -78,7 +78,10 @@ class Client(object):
             body = body.encode('utf8')
             kwargs["data"] = body
         if "files" in kwargs:
-            kwargs['data'] = kwargs['files']
+            data = aiohttp.FormData()
+            for k, v in kwargs['files'].items():
+                data.add_field(k, **v)
+            kwargs['data'] = data
             del kwargs['files']
         async with aiohttp.request(method=method, url=url, raise_for_status=True, **kwargs) as r:
             content = json.loads(await r.text(encoding='utf-8'))
@@ -115,10 +118,9 @@ class Client(object):
         :return: 返回token
         """
         if self._token:
-            return self._token
-            # now = time.time()
-            # if self.token_expires_at - now > 60:
-            #     return self._token
+            now = time.time()
+            if self.token_expires_at - now > 60:
+                return self._token
         json = await self.grant_token()
         self._token = json["access_token"]
         self.token_expires_at = int(time.time()) + json["expires_in"]
